import { Wallet, XrplNetwork } from 'xpring-common-js';
import { BigInteger } from 'big-integer';
import XrpClientDecorator from './xrp-client-decorator';
import RawTransactionStatus from './raw-transaction-status';
import TransactionStatus from './transaction-status';
import XrpTransaction from './model/xrp-transaction';
import SendXrpDetails from './model/send-xrp-details';
import TransactionResult from './model/transaction-result';
/**
 * An XrpClient which blocks on `send` calls until the transaction has reached a deterministic state.
 */
export default class ReliableSubmissionXrpClient implements XrpClientDecorator {
    private readonly decoratedClient;
    readonly network: XrplNetwork;
    constructor(decoratedClient: XrpClientDecorator, network: XrplNetwork);
    getBalance(address: string): Promise<BigInteger>;
    getPaymentStatus(transactionHash: string): Promise<TransactionStatus>;
    send(amount: string | number | BigInteger, destination: string, sender: Wallet): Promise<string>;
    sendWithDetails(sendXrpDetails: SendXrpDetails): Promise<string>;
    getLatestValidatedLedgerSequence(address: string): Promise<number>;
    getRawTransactionStatus(transactionHash: string): Promise<RawTransactionStatus>;
    accountExists(address: string): Promise<boolean>;
    paymentHistory(address: string): Promise<Array<XrpTransaction>>;
    getPayment(transactionHash: string): Promise<XrpTransaction | undefined>;
    enableDepositAuth(wallet: Wallet): Promise<TransactionResult>;
    /**
     * Waits for a transaction to complete and returns a TransactionResult.
     *
     * @param transactionHash The transaction to wait for.
     * @param wallet The wallet sending the transaction.
     *
     * @returns A Promise resolving to a TransactionResult containing the results of the transaction associated with
     * the given transaction hash.
     */
    private awaitFinalTransactionResult;
    private determineFinalResult;
    private awaitFinalTransactionStatus;
}
